@@ -388,7 +388,8 @@ class Classes(models.Model):
         """
         # structure : [(regexp de sélection, regexp d'interdiction)]
         # vérifier que json.loads fonctionnera après traduction aussi !
-        CLASSE_CAUTION_RE = json.loads('[["^2D.*", "^2D00.*"], ["^1.*", ""], ["^TMC.*", ""], ["^TRH.*", ""], ["^TG[0-9]", ""]]')
+        # Translators: this is a list of regexps to select/unselect important classes
+        CLASSE_CAUTION_RE = json.loads(_('[["^2D.*", "^2D00.*"], ["^1.*", ""], ["^TMC.*", ""], ["^TRH.*", ""], ["^TG[0-9]", ""], ["^TGF.*", ""]]'))
         Qsums=[]
         for rselect, rnot in  CLASSE_CAUTION_RE:
             if rnot:
@@ -397,7 +398,7 @@ class Classes(models.Model):
             else:
                 Qsums.append(Q(libelle__regex = rselect))
         Qsum = reduce(or_, Qsums)
-        return Classes.objects.filter(Qsum).filter(compte__gt = 0).order_by('libelle')
+        return Classes.objects.filter(Qsum).order_by('libelle')
     
     def recompte(self):
         """
@@ -983,6 +984,32 @@ class Eleves_abstract(models.Model):
         verbose_name = _("Adresse d'un autre représentant légal"),
         blank=True, null=True)
 
+    def adresse_codepostal(self):
+        """
+        Prépare l'adresse pour imprimer sur une étiquette ;
+        découvre le code postal, puis met tout ce qui commence au code postal
+        à part.
+        @return une paire : (debut, code)
+        """
+        a = re.sub(r"\sfrance", "", self.Adresse_Repr_Leg,
+                   re.MULTILINE, re.IGNORECASE)
+        lignes = a.strip().split("\n")
+        index_code = None
+        debut = a; code = ""
+        for i in range(len(lignes)):
+            if re.match(r"\d\d\d\d\d", lignes[i]):
+                index_code = i
+        if index_code is not None: # on connaît la ligne du code postal
+            if index_code > 0 : # le code n'est pas en première ligne
+                debut = "\n".join(lignes[: index_code -1])
+                # si le code postal est tout en dernier alors
+                # on inverse les deux dernières lignes
+                if index_code == len(lignes) - 1:
+                    code = lignes[index_code] + "\n" + lignes[index_code -1]
+                else:
+                    code = "\n".join(lignes[index_code -1 :])
+        return debut, code
+    
     def nom_prenom(self):
         return f"{self.Nom_de_famille} {self.Prenom}"
 
@@ -1565,7 +1592,8 @@ class Eleves_de_siecle(Eleves_abstract):
             # valeur par défaut des la classe = 'PAS DE CLASSE'
             if 'Lib_Structure' not in args or not args['Lib_Structure']:
                 args['Lib_Structure'] = 'PAS DE CLASSE'
-            yield Eleves_de_siecle(**args)
+            result = Eleves_de_siecle(**args)
+            yield result
         return
 
 class Materiel(models.Model):
@@ -1642,6 +1670,13 @@ class Materiel(models.Model):
         Remplace les espaces par des <br>
         """
         return self.abrege.replace(" ", "<br>").upper()
+
+    @property
+    def is_poche(self):
+        """
+        vrai si c'est un livre à lire
+        """
+        return self.abrege.lower().strip() == 'poche'
     
     @property
     def float_prix(self):
@@ -2033,7 +2068,9 @@ class Caution(models.Model):
     somme_rendue = FloatField(verbose_name = _("Somme rendue"), blank=True, default=0)
     commentaire = CharField(
         max_length=140, verbose_name = _("Commentaire"), blank=True, default = "")
-
+    sans_accent = CharField(
+        max_length=50, verbose_name = _("Nom sans accents"),
+        blank=True, null=True )
 
     def __str__(self):
         if self.somme_payee == 0:
@@ -2054,6 +2091,19 @@ class Caution(models.Model):
                 )
         return result
 
+    @property
+    def nomprenom(self):
+        return f"{self.nom} {self.prenom}"
+
+    def calcule_sans_accent(self):
+        """
+        Crée une version sans accents, ni tirets ni apostrophes, en minuscules
+        du nom/prénom, et l'affecte à self.sans_accent
+        """
+        self.sans_accent = sans_accent(
+            self.nom + " " + self.prenom).lower()
+        return
+
     @staticmethod
     def next_no_caution():
         """
