@@ -893,7 +893,6 @@ def importeFromGemaSCO(request):
     modeles = {}
     for mod in modeles_ordre:
         # création d'un arbre de dépendances
-        print("GRRRRR mod =", mod)
         the_class = eval(mod)
         related = [f.related_model.__name__ for f in the_class._meta.fields \
                    if isinstance(f, django.db.models.fields.related.ForeignKey)]
@@ -1184,10 +1183,15 @@ def moisson(request):
     """
     abreges = request.POST.get("livres")
     abreges = abreges.split(",")
+    textes = request.POST.get("txt")
+    if textes:
+        textes = [t.strip() for t in textes.split(",")]
+    else:
+        textes = len(abreges) * [""]
     manuels = []
-    for a in abreges:
+    for a,t in zip(abreges, textes):
         ids = [m.id for m in Materiel.objects.filter(abrege = a)]
-        manuels.append({"abrege": a, "ids": ids})
+        manuels.append({"abrege": a, "ids": ids, "txt": t})
     tous_manuels = []
     tous_abreges = {m.abrege for m in Materiel.objects.all()}
     for a in tous_abreges:
@@ -1558,3 +1562,36 @@ def abreges(request, svgfile, multiplicateur):
             "svgfile": os.path.basename(svgfile),
             "multiplicateur": multiplicateur,
         })
+
+def choix_eleves(request):
+    """
+    Crée des sélections d'élèves pour faire des traitements automatisés
+    avec la liste choisie, comme imprimer des étiquettes de courrier, etc.
+    """
+    return render_common(
+        request,
+        'gestion/choix_eleves.html',
+        _("Actions sur des élèves à choisir"),
+        {
+            "aide": "choix_eleves",
+        })
+
+def action_courrier(request):
+    """
+    Gestion d'étiquettes d'adresses postales pour des élèves choisis
+    Le POST contient un paramètre noms
+    """
+    noms = request.POST.get("noms")
+    #eleves = Eleves.objects.filter(NomPrenomEleve__in = noms)
+    return render_common(
+        request,
+        'gestion/action_courrier.html',
+        _("Étiquettes pour des courriers aux élèves"),
+        {
+            "aide": "action_courrier",
+            "noms": noms,
+            "lignes": list(range(1, 1+8)),
+            "colonnes": list(range(1, 1+3)),
+        })
+
+    
